<?php
/**
 * Woo Dognet
 *
 * @package   Woo Dognet
 * @author    Vladislav Musílek
 * @license   GPL-2.0+
 * @copyright 2014 Vladislav Musílek
 */

class Woo_Dognet {

	/**
	 * Plugin version, used for cache-busting of style and script file references.
	 *
	 * @since   1.0.0
	 *
	 * @var     string
	 */
	const VERSION = '1.2';

	/**
	 * Unique identifier for your plugin.
	 *    
	 * @since    1.0.0
	 *
	 * @var      string
	 */
	protected $plugin_slug = 'woo-dognet';

	/**
	 * Instance of this class.
	 *
	 * @since    1.0.0
	 *
	 * @var      object
	 */
	protected static $instance = null;

	/**
	 * Initialize the plugin by setting localization and loading public scripts
	 * and styles.
	 *
	 * @since     1.0.0
	 */
	private function __construct() {

		// Activate plugin when new blog is added
		add_action( 'wpmu_new_blog', array( $this, 'activate_new_site' ) );

    	add_action( 'wp_head', array( $this, 'dognet_script') );
    	add_action( 'wp_footer', array( $this, 'tracking_code') );
		add_action( 'woocommerce_thankyou', array( $this, 'conversion_code' ) );
	}

	/**
	 * Return the plugin slug.
	 *
	 * @since    1.0.0
	 *
	 * @return    string Plugin slug variable.
	 */
	public function get_plugin_slug() {
		return $this->plugin_slug;
	}

	/**
	 * Return an instance of this class.
	 *
	 * @since     1.0.0
	 *
	 * @return    object    A single instance of this class.
	 */
	public static function get_instance() {

		// If the single instance hasn't been set, set it now.
		if ( null === self::$instance ) {
			self::$instance = new self;
		}

		return self::$instance;
	}

	/**
	 * Fired when the plugin is activated.
	 *
	 * @since    1.0.0
	 *
	 * @param    boolean    $network_wide    True if WPMU superadmin uses
	 *                                       "Network Activate" action, false if
	 *                                       WPMU is disabled or plugin is
	 *                                       activated on an individual blog.
	 */
	public static function activate( $network_wide ) {

		if ( function_exists( 'is_multisite' ) && is_multisite() ) {

			if ( $network_wide  ) {

				// Get all blog ids
				$blog_ids = self::get_blog_ids();

				foreach ( $blog_ids as $blog_id ) {

					switch_to_blog( $blog_id );
					self::single_activate();
				}

				restore_current_blog();

			} else {
				self::single_activate();
			}

		} else {
			self::single_activate();
		}

	}

	/**
	 * Fired when the plugin is deactivated.
	 *
	 * @since    1.0.0
	 *
	 * @param    boolean    $network_wide    True if WPMU superadmin uses
	 *                                       "Network Deactivate" action, false if
	 *                                       WPMU is disabled or plugin is
	 *                                       deactivated on an individual blog.
	 */
	public static function deactivate( $network_wide ) {

		if ( function_exists( 'is_multisite' ) && is_multisite() ) {

			if ( $network_wide ) {

				// Get all blog ids
				$blog_ids = self::get_blog_ids();

				foreach ( $blog_ids as $blog_id ) {

					switch_to_blog( $blog_id );
					self::single_deactivate();

				}

				restore_current_blog();

			} else {
				self::single_deactivate();
			}

		} else {
			self::single_deactivate();
		}

	}

	/**
	 * Fired when a new site is activated with a WPMU environment.
	 *
	 * @since    1.0.0
	 *
	 * @param    int    $blog_id    ID of the new blog.
	 */
	public function activate_new_site( $blog_id ) {

		if ( 1 !== did_action( 'wpmu_new_blog' ) ) {
			return;
		}

		switch_to_blog( $blog_id );
		self::single_activate();
		restore_current_blog();

	}

	/**
	 * Get all blog ids of blogs in the current network that are:
	 * - not archived
	 * - not spam
	 * - not deleted
	 *
	 * @since    1.0.0
	 *
	 * @return   array|false    The blog ids, false if no matches.
	 */
	private static function get_blog_ids() {

		global $wpdb;

		// get an array of blog ids
		$sql = "SELECT blog_id FROM {$wpdb->blogs}
			WHERE archived = '0' AND spam = '0'
			AND deleted = '0'";

		return $wpdb->get_col( $sql );

	}

	/**
	 * Fired for each blog when the plugin is activated.
	 *
	 * @since    1.0.0
	 */
	private static function single_activate() {
	}

	/**
	 * Fired for each blog when the plugin is deactivated.
	 *
	 * @since    1.0.0
	 */
	private static function single_deactivate() {
	}


	/**
	 * Conversion code
	 *
	 * @since    1.0.0
	 */
	public function conversion_code( $order_id ) {
		$option = get_option( 'woo_dognet' );
  		if( !empty( $option['account_id'] ) ){
			
			$order = wc_get_order( $order_id );

			$version = toret_check_wc_version();

        	if( $version === false ){

            	$currency = $order->get_order_currency();   
                    
        	}else{

	            $currency = $order->get_currency();            	

        	}

		    $orderTotal = 0;

			$productNames = array();
		    foreach($order->get_items() as $item_id => $item) {
		    	$item_total = $order->get_item_meta($item_id, '_line_total', true);
		    	$orderTotal += $item_total;
			    $productNames[] = $item['name'];
		    }
    	?>
            <!-- Měřicí kód Dognet.cz -->
            <script type="text/javascript">
                PostAffTrackerdognet.setAccountId('<?php echo $option['account_id'];  ?>');

                var action = PostAffTrackerdognet.createSale();

                <?php if (!empty($option['campaign_id'])) { ?>
                    action.setCampaignID('<?php echo $option['campaign_id']; ?>');
                <?php } ?>

                action.setTotalCost('<?php echo number_format ( $orderTotal, 2 ,"." ,"" ) ?>');
                action.setOrderID('<?php echo $order_id ?>');
                action.setProductID('<?php echo implode(', ', $productNames) ?>');
                action.setCurrency('<?php echo $currency; ?>');

                <?php foreach($order->get_items( 'coupon' ) as $item_id => $item) { ?>
                    action.setCoupon('<?php echo $item->get_code(); ?>');
                <?php } ?>

                PostAffTrackerdognet.register();
            </script>
		    <?php
    	}
	}

	/**
	 * Retargeting code
	 *
	 * @since    1.0.0
	 */     
  public function tracking_code(){
  		$option = get_option( 'woo_dognet' );
  		if( !empty( $option['account_id'] ) ){
  			?>
            <script type="text/javascript"><!--
                PostAffTrackerdognet.setAccountId('<?php echo $option['account_id'];  ?>');
                try {
                    PostAffTrackerdognet.track();
                } catch (err) { }
                //-->
            </script>
            <?php
  		}
  }

	public function dognet_script() {
        echo '<script type="text/javascript" id="pap_x2s6df8ddognet" src="https://login.dognet.sk//scripts/trackjs.php?pap_tracking_suffix=dognet"></script>';
  }
}//End class
